@@ -1,6 +1,6 @@
 <?php
 /**
- * @version		$Id: html.php 3939 2011-01-19 10:27:12Z fishbone $
+ * @version		$Id: html.php 4955 2012-06-09 10:11:23Z fishbone $
  * @package		Joomla.Framework
  * @subpackage	HTML
  * @copyright	Copyright (C) 2005 - 2007 Open Source Matters. All rights reserved.
@@ -32,7 +32,7 @@ class JHTML
 	 *                  prefix and class are optional and can be used to load custom
 	 *                  html helpers.
 	 */
-	function _( $type )
+	public static function _( $type )
 	{
 		global $gEnvManager;
 		
@@ -104,7 +104,7 @@ class JHTML
 	 * @param	array	An associative array of attributes to add
 	 * @since	1.5
 	 */
-	function link($url, $text, $attribs = null)
+	public static function link($url, $text, $attribs = null)
 	{
 		if (is_array( $attribs )) {
 			$attribs = JArrayHelper::toString( $attribs );
@@ -122,7 +122,7 @@ class JHTML
 	 * @param	array	An associative array of attributes to add
 	 * @since	1.5
 	 */
-	function image($url, $alt, $attribs = null)
+	public static function image($url, $alt, $attribs = null)
 	{
 		if (is_array($attribs)) {
 			$attribs = JArrayHelper::toString( $attribs );
@@ -145,7 +145,7 @@ class JHTML
 	 * @param	string	The message to display if the iframe tag is not supported
 	 * @since	1.5
 	 */
-	function iframe( $url, $name, $attribs = null, $noFrames = '' )
+	public static function iframe( $url, $name, $attribs = null, $noFrames = '' )
 	{
 		if (is_array( $attribs )) {
 			$attribs = JArrayHelper::toString( $attribs );
@@ -163,7 +163,7 @@ class JHTML
 	 * @param	boolean If true, the mootools library will be loaded
 	 * @since	1.5
 	 */
-	function script($filename, $path = 'media/system/js/', $mootools = true)
+	public static function script($filename, $path = 'media/system/js/', $mootools = true)
 	{
 		// Include mootools framework
 		if($mootools) {
@@ -186,7 +186,7 @@ class JHTML
 	 * @param	string 	The relative URL to use for the href attribute
 	 * @since	1.5
 	 */
-	function stylesheet($filename, $path = 'media/system/css/', $attribs = array())
+	public static function stylesheet($filename, $path = 'media/system/css/', $attribs = array())
 	{
 		if(strpos($path, 'http') !== 0) {
 			$path =  JURI::root(true).'/'.$path;
@@ -207,7 +207,7 @@ class JHTML
 	 * @see		strftime
 	 * @since	1.5
 	 */
-	function date($date, $format = null, $offset = NULL)
+	public static function date($date, $format = null, $offset = NULL)
 	{
 		if ( ! $format ) {
 			$format = JText::_('DATE_FORMAT_LC1');
@@ -239,7 +239,7 @@ class JHTML
 	 * @return	string
 	 * @since	1.5
 	 */
-	function tooltip($tooltip, $title='', $image='tooltip.png', $text='', $href='', $link=1)
+	public static function tooltip($tooltip, $title='', $image='tooltip.png', $text='', $href='', $link=1)
 	{
 		$tooltip	= addslashes(htmlspecialchars($tooltip));
 		$title		= addslashes(htmlspecialchars($title));
@@ -277,7 +277,7 @@ class JHTML
 	 * @param	string	The date format
 	 * @param	array	Additional html attributes
 	 */
-	function calendar($value, $name, $id, $format = '%Y-%m-%d', $attribs = null)
+	public static function calendar($value, $name, $id, $format = '%Y-%m-%d', $attribs = null)
 	{
 		JHTML::_('behavior.calendar'); //load the calendar behavior
 
@@ -306,7 +306,7 @@ class JHTML
 	 * @return	array	An array with directory elements
 	 * @since	1.5
 	 */
-	function addIncludePath( $path='' )
+	public static function addIncludePath( $path='' )
 	{
 		static $paths;
 
