@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_std.sql 4702 2012-02-19 14:59:56Z fishbone $
+-- * @version    SVN: $Id: insert_std.sql 4996 2012-06-28 03:42:28Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -52,7 +52,14 @@ INSERT INTO blog_config
 ('category_count',          '2',         '記事に設定可能なカテゴリ数',         10),
 ('m:entry_view_count',      '3',         '記事表示数(携帯)',                   11),
 ('m:entry_view_order',      '1',         '記事表示順(携帯)',                   12),
-('m:title_color',           '',         'タイトルの背景色',                    13);
+('m:title_color',           '',         'タイトルの背景色',                    13),
+('s:entry_view_count',        '10',        '記事表示数',                         100),
+('s:entry_view_order',        '1',         '記事表示順',                         101),
+('s:top_content',  '',          'トップ画面コンテンツ', 102),
+('s:auto_resize_image_max_size',  '280',      '画像の自動変換最大サイズ',           103),
+('s:jquery_view_style',       '1',      'jQueryMobile表示スタイル',           104),
+('s:use_title_list_image',       '1',      'タイトルリスト画像を使用',           105),
+('s:title_list_image',       '',      'タイトルリスト画像',           106);
 
 -- BBS設定マスター
 INSERT INTO bbs_config (sf_id,                     sf_value,    sf_name,                        sf_index)
@@ -334,7 +341,17 @@ INSERT INTO photo_config
 ('photo_list_order',        '0',         '画像一覧表示順',                         10),
 ('photo_title_short_length',  '10',                '画像タイトル(略式)文字数',         11),
 ('photo_category_password', '0',                '画像カテゴリーのパスワード制限',             12),
-('thumbnail_crop',      '1',                'サムネール画像切り取り',         13);
+('thumbnail_crop',      '1',                'サムネール画像切り取り',         13),
+('image_size',          '450',              '公開画像サイズ',               14),
+('thumbnail_size',      '128',              'サムネール画像サイズ',         15),
+('image_quality',       '100',              '画像の品質',                   16),
+('photo_list_sort_key', 'index',            '画像一覧のソートキー',         17),
+('s:photo_list_item_count',  '24',                '画像一覧表示項目数',         200),
+('s:photo_list_order',        '1',         '画像一覧表示順',                         201),
+('s:photo_title_short_length',  '7',                '画像タイトル(略式)文字数',         202),
+('s:photo_list_sort_key', 'index',            '画像一覧のソートキー',         203),
+('s:default_image_size',      '320',              '公開画像デフォルトサイズ',               204),
+('s:default_thumbnail_size',  '128',              'サムネール画像デフォルトサイズ',         205);
 
 -- --------------------------------------------------------------------------------------------------
 -- 携帯クイズ王ウィジェット用
