@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainWidgetContainer.php 4466 2011-11-25 02:25:22Z fishbone $
+ * @version    SVN: $Id: admin_mainWidgetContainer.php 5107 2012-08-13 06:04:45Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -20,9 +20,6 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 {
 	private $redirectUrl;		// リダイレクト先URL
 	private $content;			// メッセージ用コンテンツ
-	private $headTitle;		// METAタグタイトル
-	private $headDesc;		// METAタグ要約
-	private $headKeyword;	// METAタグキーワード
 	const CF_USE_CONTENT_MAINTENANCE = 'use_content_maintenance';		// メンテナンス画面に汎用コンテンツを使用するかどうか
 	const CF_USE_CONTENT_ACCESS_DENY = 'use_content_access_deny';		// アクセス不可画面に汎用コンテンツを使用するかどうか
 	
@@ -209,7 +206,6 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 					} else if (strncmp($task, 'showpage_', strlen('showpage_')) == 0){// $taskが「showpage_xxxx」タイプの場合の処理
 						$task = 'showpage';
 					}
-
 					// コンテナを起動
 					switch ($task){
 						case 'test';			// テスト用画面
@@ -333,23 +329,6 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 		$localeText['label_password'] = $this->_('Password');		// パスワード
 		$this->setLocaleText($localeText);
 	}
-	/**
-	 * ヘッダ部メタタグの設定
-	 *
-	 * HTMLのheadタグ内に出力する。
-	 * _assign()よりも後に実行される。
-	 *
-	 * @param RequestManager $request		HTTPリクエスト処理クラス
-	 * @param object         $param			任意使用パラメータ
-	 * @return array 						設定データ。連想配列で「title」「description」「keywords」を設定。
-	 */
-	function _setHeadMeta($request, &$param)
-	{
-		$headData = array(	'title' => $this->headTitle,
-							'description' => $this->headDesc,
-							'keywords' => $this->headKeyword);
-		return $headData;
-	}
 	/**
 	 * アクセスポイントから汎用コンテンツのタイプを取得
 	 *
