@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: breadcrumbWidgetContainer.php 3529 2010-08-25 09:46:09Z fishbone $
+ * @version    SVN: $Id: breadcrumbWidgetContainer.php 4936 2012-06-05 09:43:49Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -113,7 +113,7 @@ class breadcrumbWidgetContainer extends BaseWidgetContainer
 		for ($i = 0; $i < count($menuItems); $i++){
 			$url = $menuItems[$i]['md_link_url'];			// マクロ表記URLを取得
 			if ($this->isRootUrl($url)){		// ルートの場合
-				$homeName = $menuItems[$i]['md_name'];
+				$homeName = $this->getCurrentLangString($menuItems[$i]['md_name']);
 				$homeUrl = $url;
 				break;
 			}
@@ -294,7 +294,7 @@ class breadcrumbWidgetContainer extends BaseWidgetContainer
 			$linkUrl = $this->getUrl($linkUrl, true/*リンク用*/);
 			
 			// メニュー項目を作成
-			$name = $this->menuItems[$menuItemId]['md_name'];
+			$name = $this->getCurrentLangString($this->menuItems[$menuItemId]['md_name']);
 			if (empty($name)) $name = self::MENU_ITEM_NONAME;
 			
 			// リンクの間にアイコンを挿入
