@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: chacha_mainThreadWidgetContainer.php 3348 2010-07-07 10:20:18Z fishbone $
+ * @version    SVN: $Id: chacha_mainThreadWidgetContainer.php 3362 2010-07-10 03:08:21Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/chacha_mainBaseWidgetContainer.php');
@@ -56,7 +56,7 @@ class chacha_mainThreadWidgetContainer extends chacha_mainBaseWidgetContainer
 	{
 		$act = $request->trimValueOf('act');
 		$postTicket = $request->trimValueOf('ticket');		// POST確認用
-		$pageNo = $request->trimIntValueOf(M3_REQUEST_PARAM_PAGE_NO);				// ページ番号
+		$pageNo = $request->trimIntValueOf(M3_REQUEST_PARAM_PAGE_NO, '1');				// ページ番号
 		if (empty($pageNo)) $pageNo = 1;
 		$messageId = $request->trimValueOf(self::URL_PARAM_MESSAGE_ID);		// メッセージID
 		$message = $request->trimValueOf('message');		// 投稿メッセージ
