@@ -10,10 +10,10 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentHistoryWidgetContainer.php 4929 2012-05-29 10:47:25Z fishbone $
+ * @version    SVN: $Id: admin_default_contentHistoryWidgetContainer.php 4970 2012-06-15 10:51:03Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_default_contentBaseWidgetContainer.php');
+require_once($gEnvManager->getWidgetContainerPath('default_content') . '/admin_default_contentBaseWidgetContainer.php');
 
 class admin_default_contentHistoryWidgetContainer extends admin_default_contentBaseWidgetContainer
 {
@@ -65,7 +65,7 @@ class admin_default_contentHistoryWidgetContainer extends admin_default_contentB
 		$maxListCount = self::DEFAULT_LIST_COUNT;
 		
 		// コンテンツ総数を取得
-		$this->totalCount = self::$_mainDb->getContentHistoryCount($contentId, $langId);
+		$this->totalCount = self::$_mainDb->getContentHistoryCount(default_contentCommonDef::$_contentType, $contentId, $langId);
 
 		// 表示するページ番号の修正
 		$pageCount = (int)(($this->totalCount -1) / $maxListCount) + 1;		// 総ページ数
@@ -87,7 +87,7 @@ class admin_default_contentHistoryWidgetContainer extends admin_default_contentB
 		}
 		
 		// コンテンツ編集履歴を取得
-		self::$_mainDb->getContentHistory($contentId, $langId, $maxListCount, $pageNo, array($this, 'itemListLoop'));
+		self::$_mainDb->getContentHistory(default_contentCommonDef::$_contentType, $contentId, $langId, $maxListCount, $pageNo, array($this, 'itemListLoop'));
 		
 		$this->tmpl->addVar("_widget", "page", $pageNo);
 		$this->tmpl->addVar("_widget", "page_link", $pageLink);
