@@ -8,17 +8,15 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_dispWidgetContainer.php 4479 2011-11-27 13:51:34Z fishbone $
+ * @version    SVN: $Id: admin_ec_dispWidgetContainer.php 5167 2012-09-06 01:29:46Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
-//require_once($gEnvManager->getCurrentWidgetDbPath() .	'/ec_dispDb.php');
 
 class admin_ec_dispWidgetContainer extends baseAdminWidgetContainer
 {
-//	private $db;	// DB接続オブジェクト
 	const DEFAULT_PRODUCT_COUNT = 10;				// デファオルとの表示項目数
 	const DEFAULT_TARGET_WIDGET = 'ec_main';		// 呼び出しウィジェットID
 	
@@ -29,9 +27,6 @@ class admin_ec_dispWidgetContainer extends baseAdminWidgetContainer
 	{
 		// 親クラスを呼び出す
 		parent::__construct();
-
-		// DBオブジェクト作成
-//		$this->db = new ec_dispDb();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -69,6 +64,7 @@ class admin_ec_dispWidgetContainer extends baseAdminWidgetContainer
 			$this->checkSingleByte($targetWidget, 'カート表示ウィジェット');
 			
 			if ($this->getMsgCount() == 0){			// エラーのないとき
+				$paramObj = new stdClass;
 				$paramObj->productCount	= $productCount;		// 商品表示数
 				$paramObj->targetWidget = $targetWidget;		// カート表示ウィジェット
 				$ret = $this->updateWidgetParamObj($paramObj);
