@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_categoryDb.php 4382 2011-10-07 04:06:36Z fishbone $
+ * @version    SVN: $Id: photo_categoryDb.php 4516 2011-12-24 13:32:07Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -33,15 +33,17 @@ class photo_categoryDb extends BaseDb
 	 *
 	 * @param string	$lang				言語
 	 * @param function	$callback			コールバック関数
+	 * @param bool      $onlyVisible		表示可能なカテゴリーのみ取得
 	 * @return 			なし
 	 */
-	function getAllCategory($lang, $callback)
+	function getAllCategory($lang, $callback, $onlyVisible=false)
 	{
 		$queryStr = 'SELECT * FROM photo_category LEFT JOIN _login_user ON hc_create_user_id = lu_id AND lu_deleted = false ';
 		$queryStr .=  'WHERE hc_language_id = ? ';
 		$queryStr .=    'AND hc_deleted = false ';		// 削除されていない
+		if ($onlyVisible) $queryStr .=    'AND hc_visible = true ';		// 表示可能項目のみ
 		$queryStr .=  'ORDER BY hc_sort_order';
-		$this->selectLoop($queryStr, array($lang), $callback, null);
+		$this->selectLoop($queryStr, array($lang), $callback);
 	}
 	/**
 	 * 画像親カテゴリー一覧を取得
@@ -115,6 +117,7 @@ class photo_categoryDb extends BaseDb
 	 * @param int	  $id	カテゴリーID
 	 * @param string  $lang			言語ID
 	 * @param string  $name			名前
+	 * @param string  $password		パスワード
 	 * @param int     $pcategory	親カテゴリーID
 	 * @param int     $index		表示順
 	 * @param bool    $visible		表示、非表示
@@ -122,7 +125,7 @@ class photo_categoryDb extends BaseDb
 	 * @param int     $newSerial	新規シリアル番号
 	 * @return bool					true = 成功、false = 失敗
 	 */
-	function addCategory($id, $lang, $name, $pcategory, $index, $visible, $userId, &$newSerial)
+	function addCategory($id, $lang, $name, $password, $pcategory, $index, $visible, $userId, &$newSerial)
 	{	
 		// トランザクション開始
 		$this->startTransaction();
@@ -157,10 +160,10 @@ class photo_categoryDb extends BaseDb
 		
 		// データを追加
 		$queryStr = 'INSERT INTO photo_category ';
-		$queryStr .=  '(hc_id, hc_language_id, hc_history_index, hc_name, hc_parent_id, hc_sort_order, hc_visible, hc_create_user_id, hc_create_dt) ';
+		$queryStr .=  '(hc_id, hc_language_id, hc_history_index, hc_name, hc_password, hc_parent_id, hc_sort_order, hc_visible, hc_create_user_id, hc_create_dt) ';
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, now())';
-		$this->execStatement($queryStr, array($cId, $lang, $historyIndex, $name, $pcategory, $index, $visible, $userId));
+		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, now())';
+		$this->execStatement($queryStr, array($cId, $lang, $historyIndex, $name, $password, $pcategory, $index, $visible, $userId));
 		
 		// 新規のシリアル番号取得
 		$queryStr = 'select max(hc_serial) as ns from photo_category ';
@@ -171,42 +174,12 @@ class photo_categoryDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
-	/**
-	 * 画像カテゴリーをシリアル番号で取得
-	 *
-	 * @param int		$serial				シリアル番号
-	 * @param array     $row				レコード
-	 * @return bool							取得 = true, 取得なし= false
-	 */
-	function getCategoryBySerial($serial, &$row)
-	{
-		$queryStr  = 'select * from photo_category LEFT JOIN _login_user ON hc_create_user_id = lu_id AND lu_deleted = false ';
-		$queryStr .=   'WHERE hc_serial = ? ';
-		$ret = $this->selectRecord($queryStr, array($serial), $row);
-		return $ret;
-	}	
-	/**
-	 * 画像カテゴリーをカテゴリーIDで取得
-	 *
-	 * @param int		$id					カテゴリーID
-	 * @param string	$langId				言語ID
-	 * @param array     $row				レコード
-	 * @return bool							取得 = true, 取得なし= false
-	 */
-	function getCategoryByCategoryId($id, $langId, &$row)
-	{
-		$queryStr  = 'SELECT * FROM photo_category LEFT JOIN _login_user ON hc_create_user_id = lu_id AND lu_deleted = false ';
-		$queryStr .=   'WHERE hc_deleted = false ';	// 削除されていない
-		$queryStr .=   'AND hc_id = ? ';
-		$queryStr .=   'AND hc_language_id = ? ';
-		$ret = $this->selectRecord($queryStr, array($id, $langId), $row);
-		return $ret;
-	}
 	/**
 	 * 画像カテゴリーの更新
 	 *
 	 * @param int     $serial		シリアル番号
 	 * @param string  $name			名前
+	 * @param string  $password		パスワード
 	 * @param int     $pcategory	親カテゴリーID
 	 * @param int     $index		表示順
 	 * @param bool    $visible		表示、非表示
@@ -214,7 +187,7 @@ class photo_categoryDb extends BaseDb
 	 * @param int     $newSerial	新規シリアル番号
 	 * @return bool					true = 成功、false = 失敗
 	 */
-	function updateCategory($serial, $name, $pcategory, $index, $visible, $userId, &$newSerial)
+	function updateCategory($serial, $name, $password, $pcategory, $index, $visible, $userId, &$newSerial)
 	{	
 		$now = date("Y/m/d H:i:s");	// 現在日時
 				
@@ -269,10 +242,10 @@ class photo_categoryDb extends BaseDb
 		
 		// 新規レコード追加
 		$queryStr = 'INSERT INTO photo_category ';
-		$queryStr .=  '(hc_id, hc_language_id, hc_history_index, hc_name, hc_parent_id, hc_sort_order, hc_visible, hc_create_user_id, hc_create_dt) ';
+		$queryStr .=  '(hc_id, hc_language_id, hc_history_index, hc_name, hc_password, hc_parent_id, hc_sort_order, hc_visible, hc_create_user_id, hc_create_dt) ';
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?)';
-		$this->execStatement($queryStr, array($row['hc_id'], $row['hc_language_id'], $historyIndex, $name, $pcategory, $index, $visible, $userId, $now));
+		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
+		$this->execStatement($queryStr, array($row['hc_id'], $row['hc_language_id'], $historyIndex, $name, $password, $pcategory, $index, $visible, $userId, $now));
 
 		// 新規のシリアル番号取得
 		$queryStr = 'select max(hc_serial) as ns from photo_category ';
@@ -283,6 +256,37 @@ class photo_categoryDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
+	/**
+	 * 画像カテゴリーをシリアル番号で取得
+	 *
+	 * @param int		$serial				シリアル番号
+	 * @param array     $row				レコード
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function getCategoryBySerial($serial, &$row)
+	{
+		$queryStr  = 'select * from photo_category LEFT JOIN _login_user ON hc_create_user_id = lu_id AND lu_deleted = false ';
+		$queryStr .=   'WHERE hc_serial = ? ';
+		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		return $ret;
+	}	
+	/**
+	 * 画像カテゴリーをカテゴリーIDで取得
+	 *
+	 * @param int		$id					カテゴリーID
+	 * @param string	$langId				言語ID
+	 * @param array     $row				レコード
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function getCategoryByCategoryId($id, $langId, &$row)
+	{
+		$queryStr  = 'SELECT * FROM photo_category LEFT JOIN _login_user ON hc_create_user_id = lu_id AND lu_deleted = false ';
+		$queryStr .=   'WHERE hc_deleted = false ';	// 削除されていない
+		$queryStr .=   'AND hc_id = ? ';
+		$queryStr .=   'AND hc_language_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($id, $langId), $row);
+		return $ret;
+	}
 	/**
 	 * 親画像カテゴリーの更新
 	 *
