@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_static_contentWidgetContainer.php 3989 2011-02-10 05:15:47Z fishbone $
+ * @version    SVN: $Id: admin_static_contentWidgetContainer.php 4690 2012-02-16 15:37:54Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -19,14 +19,13 @@ require_once($gEnvManager->getCurrentWidgetDbPath() . '/static_contentDb.php');
 class admin_static_contentWidgetContainer extends BaseAdminWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;	// DB接続オブジェクト
 	private $serialNo;		// 選択中の項目のシリアル番号
 	private $serialArray = array();			// 表示中のシリアル番号
 	private $langId;
 	private $paramObj;		// パラメータ保存用オブジェクト
 	private $contentId;		// コンテンツID
+	private $menuHtml;	// コンテンツメニュー
 	const DEFAULT_NAME_HEAD = '名称未設定';			// デフォルトの設定名
-	const CONTENT_TYPE = 'news';			// コンテンツタイプ
 	const CONTENT_WIDGET_ID = 'default_content';			// コンテンツ編集ウィジェット
 	
 	/**
@@ -39,7 +38,6 @@ class admin_static_contentWidgetContainer extends BaseAdminWidgetContainer
 		
 		// DBオブジェクト作成
 		$this->db = new static_contentDb();
-		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -96,7 +94,7 @@ class admin_static_contentWidgetContainer extends BaseAdminWidgetContainer
 		
 		// 入力値を取得
 		$name = $request->trimValueOf('item_name');
-		$hideInLogin = ($request->trimValueOf('item_hide_in_login') == 'on') ? 1 : 0;		// ログイン中は非表示にする
+//		$hideInLogin = ($request->trimValueOf('item_hide_in_login') == 'on') ? 1 : 0;		// ログイン中は非表示にする
 		$this->contentId = $request->trimValueOf('contentid');	// コンテンツID
 		$this->configId = $request->trimValueOf('item_id');		// 定義ID
 		if (empty($this->configId)) $this->configId = $defConfigId;		// 呼び出しウィンドウから引き継いだ定義ID
@@ -126,7 +124,7 @@ class admin_static_contentWidgetContainer extends BaseAdminWidgetContainer
 				$newObj = new stdClass;
 				$newObj->name	= $name;// 表示名
 				$newObj->contentId = $this->contentId;		// コンテンツID
-				$newObj->hideInLogin	= $hideInLogin;		// ログイン中は非表示にする
+//				$newObj->hideInLogin	= $hideInLogin;		// ログイン中は非表示にする
 				
 				$ret = $this->addPageDefParam($defSerial, $defConfigId, $this->paramObj, $newObj);
 				if ($ret){
@@ -146,7 +144,7 @@ class admin_static_contentWidgetContainer extends BaseAdminWidgetContainer
 				if ($ret){
 					// ウィジェットオブジェクト更新
 					$targetObj->contentId = $this->contentId;
-					$targetObj->hideInLogin	= $hideInLogin;		// ログイン中は非表示にする
+//					$targetObj->hideInLogin	= $hideInLogin;		// ログイン中は非表示にする
 				}
 				
 				// 設定値を更新
@@ -159,6 +157,19 @@ class admin_static_contentWidgetContainer extends BaseAdminWidgetContainer
 					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
 				}
 			}
+		} else if ($act == 'getmenu'){		// コンテンツ選択メニュー取得
+			// コンテンツIDを取得
+			$contentSerial = $request->trimValueOf('content_serial');
+			$ret = $this->db->getContentBySerial($contentSerial, $row);
+			if ($ret) $this->contentId = $row['cn_id'];
+			
+			// コンテンツ選択メニューを作成
+			$this->menuHtml  = '<select name="contentid">';
+	        $this->menuHtml .= '<option value="0">-- 未選択 --</option>';
+			$this->db->getAllContentItems(array($this, 'itemListLoop'), $this->langId);
+			$this->menuHtml .= '</select>';
+			
+			$this->gInstance->getAjaxManager()->addData('menu_html', $this->menuHtml);
 		} else if ($act == 'select'){	// 定義IDを変更
 			$replaceNew = true;			// データ再取得
 		}
@@ -171,7 +182,7 @@ class admin_static_contentWidgetContainer extends BaseAdminWidgetContainer
 			$this->tmpl->setAttribute('item_name_visible', 'visibility', 'visible');// 名前入力フィールド表示
 			if ($replaceNew){		// データ再取得時
 				$name = $this->createDefaultName();			// デフォルト登録項目名
-				$hideInLogin = 0;		// ログイン中は非表示にする
+//				$hideInLogin = 0;		// ログイン中は非表示にする
 			}
 			$this->serialNo = 0;
 		} else {
@@ -180,7 +191,7 @@ class admin_static_contentWidgetContainer extends BaseAdminWidgetContainer
 				if ($ret){
 					$name = $targetObj->name;// 名前
 					$this->contentId = $targetObj->contentId;			// コンテンツID
-					$hideInLogin = $targetObj->hideInLogin;		// ログイン中は非表示にする
+//					$hideInLogin = $targetObj->hideInLogin;		// ログイン中は非表示にする
 				}
 			}
 			$this->serialNo = $this->configId;
@@ -194,10 +205,9 @@ class admin_static_contentWidgetContainer extends BaseAdminWidgetContainer
 		
 		// ### 入力値を再設定 ###
 		$this->tmpl->addVar("item_name_visible", "name", $name);		// 名前
-		$checked = '';
-		if ($hideInLogin) $checked = 'checked';
-		$this->tmpl->addVar("_widget", "hide_in_login", $checked);	// ログイン中は非表示にするかどうか
-		
+//		$checked = '';
+//		if ($hideInLogin) $checked = 'checked';
+//		$this->tmpl->addVar("_widget", "hide_in_login", $checked);	// ログイン中は非表示にするかどうか
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);// 選択中のシリアル番号、IDを設定
 		$this->tmpl->addVar('_widget', 'content_widget_id', self::CONTENT_WIDGET_ID);// コンテンツ表示ウィジェット
 		
@@ -258,6 +268,9 @@ class admin_static_contentWidgetContainer extends BaseAdminWidgetContainer
 		);
 		$this->tmpl->addVars('content_list', $row);
 		$this->tmpl->parseTemplate('content_list', 'a');
+		
+		// コンテンツ選択メニューHTML
+		$this->menuHtml .= '<option value="' . $id . '" ' . $selected . '>' . $this->convertToDispString($fetchedRow['cn_name']) . '</option>';
 		return true;
 	}
 	/**
@@ -348,7 +361,7 @@ class admin_static_contentWidgetContainer extends BaseAdminWidgetContainer
 			
 			$defCount = 0;
 			if (!empty($id)){
-				$defCount = $this->sysDb->getPageDefCount($this->gEnv->getCurrentWidgetId(), $id);
+				$defCount = $this->_db->getPageDefCount($this->gEnv->getCurrentWidgetId(), $id);
 			}
 			$operationDisagled = '';
 			if ($defCount > 0) $operationDisagled = 'disabled';
